# Deliverables

| workflow | status |
| - | - |
| `project-plan` | [![project-plan](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/project-plan.yml/badge.svg)](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/project-plan.yml) |
| `final-report` | [![final-report](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/final-report.yml/badge.svg)](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/final-report.yml) |
| `presentation` | [![presentation](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/presentation.yml/badge.svg)](https://github.com/ese-msc-2021/irp-ns1321/actions/workflows/presentation.yml) |

Before submission, please ensure your report complies with **IRP2022 guidelines**. Commit your project plan, final report, and presentation (**each as a single PDF**) to **this directory** (`reports/`). The **file name** must be (all **lowercase**):

| deliverable | filename |
| - | - |
| project plan | `ns1321-project-plan.pdf` |
| final report | `ns1321-final-report.pdf` |
| presentation | `ns1321-presentation.pdf` |

As a final step, **ensure the corresponding workflow on GitHub Actions (e.g., `project-plan`, `final-report`, or `presentation`) is passing** - workflow badges in the table above.
